@@ -144,6 +144,7 @@ var LibraryEmbind = {
     }
     else {
         Module[name] = value;
+        Module[name].argCount = numArguments;
     }
   },
 
@@ -616,6 +617,8 @@ var LibraryEmbind = {
             var getElement;
             if (value instanceof Uint8Array) {
                 getElement = getTAElement;
+            } else if (value instanceof Uint8ClampedArray) {
+                getElement = getTAElement;
             } else if (value instanceof Int8Array) {
                 getElement = getTAElement;
             } else if (typeof value === 'string') {
@@ -1947,6 +1950,8 @@ var LibraryEmbind = {
             // Replace the initial unbound-handler-stub function with the appropriate member function, now that all types
             // are resolved. If multiple overloads are registered for this function, the function goes into an overload table.
             if (undefined === proto[methodName].overloadTable) {
+                // Set argCount in case an overload is registered later
+                memberFunction.argCount = argCount - 2;
                 proto[methodName] = memberFunction;
             } else {
                 proto[methodName].overloadTable[argCount - 2] = memberFunction;
